v0.1.0 (in development)
------

- memory footprint reduced
- ``len`` support
- ``CTrie#height`` and ``CTrie#values`` methods added


v0.0.1
------

- initial release
- support for ``add`` and ``remove`` operations
- full online documentation
